/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugs.extension;

import org.eclipse.jface.action.Action;
import org.eclipse.jface.viewers.IDoubleClickListener;
import org.eclipse.jface.viewers.IOpenListener;
import org.eclipse.jface.viewers.ISelectionChangedListener;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.viewers.TreeViewer;
import org.eclipse.swt.dnd.Clipboard;
import org.eclipse.swt.dnd.DragSourceListener;
import org.eclipse.swt.dnd.DropTargetListener;
import org.eclipse.swt.dnd.Transfer;
import org.eclipse.swt.events.FocusListener;
import org.eclipse.swt.events.TreeListener;
import org.eclipse.team.bugs.model.IBugProvider;
import org.eclipse.team.bugs.model.IProviderListener;
import org.eclipse.ui.IWorkbenchPart;

/**
 * 
 */
public interface IViewerProxy {
    
    void addFocusListener(FocusListener listener);
    
    void addSelectionChangedListener(ISelectionChangedListener listener);
    
    void addProviderListener(IProviderListener listener);
    
    void addOpenListener(IOpenListener listener);
    
    void addDoubleClickListener(IDoubleClickListener listener);
    
    void addTreeListener(TreeListener listener);
    
    void removeFocusListener(FocusListener listener);
    
    void removeSelectionChangedListener(ISelectionChangedListener listener);
    
    void removeProviderListener(IProviderListener listener);
    
    void removeOpenListener(IOpenListener listener);
    
    void removeDoubleClickListener(IDoubleClickListener listener);
    
    void removeTreeListener(TreeListener listener);
    
    void registerGlobalAction(String id, Action action);
    
    IWorkbenchPart getPart();
    
    void revealCustomControl();

    Clipboard getClipboard();
    
    void addDragSupport(Transfer [] transfers, DragSourceListener listener);
    
    void removeDragSupport();
    
    public void addDropSupport(int operations, Transfer[] transfers, DropTargetListener listener);
    
    public void removeDropSupport();
    
    public TreeViewer getViewer();
    
    public IStructuredSelection getSelection();
    
    public IBugProvider getProvider();
    
    public void performUpdate(Runnable runnable);
}