package org.eclipse.team.bugs.internal.main;

import java.net.MalformedURLException;
import java.net.URL;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IExtension;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Platform;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.team.bugs.extension.BugsException;
import org.eclipse.ui.plugin.AbstractUIPlugin;

/**
 * The main plugin class to be used in the desktop.
 */
public class BugsPlugin extends AbstractUIPlugin {
    
    public static final String ID = "org.eclipse.team.bugs";
    
    private static BugsPlugin fInstance;
    
    private ResourceBundle fResourceBundle;
    
    public BugsPlugin() {
        super();
        fInstance= this;
    }
    
    public static ImageDescriptor getImageDescriptorFromExtension(IExtension extension, String subdirectoryAndFilename) {
        final URL path= Platform.getBundle(extension.getNamespace()).getEntry("/"); //$NON-NLS-1$
        try {
            final URL fullPathString= new URL(path,subdirectoryAndFilename);
            return ImageDescriptor.createFromURL(fullPathString);
        } catch (MalformedURLException e) {
        }
        return null;
    }
    
    /**
     * Returns the shared instance.
     */
    public static BugsPlugin getDefault() {
        return fInstance;
    }
    
    /**
     * Returns the string from the plugin's resource bundle,
     * or 'key' if not found.
     */
    public static String getResourceString(String key) {
        ResourceBundle bundle = BugsPlugin.getDefault().getResourceBundle();
        try {
            return (bundle != null) ? bundle.getString(key) : key;
        } catch (MissingResourceException e) {
            return key;
        }
    }
    
    /**
     * Returns the plugin's resource bundle,
     */
    public ResourceBundle getResourceBundle() {
        try {
            if (fResourceBundle == null)
                fResourceBundle = ResourceBundle.getBundle("org.eclipse.team.bugs.core.BugsPluginResources");
        } catch (MissingResourceException x) {
            fResourceBundle = null;
        }
        return fResourceBundle;
    }
    
    public static void log(Exception e) {
        if (e instanceof CoreException) {
            log(((CoreException)e).getStatus());
        } else {
            log(BugsException.asBugsException(e));
        }
    }
    
    public static void log(IStatus status) {
        getDefault().getLog().log(status);
    }
}
