/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.team.bugs.internal.registry;

import java.util.HashMap;
import java.util.Map;

import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IConfigurationElement;
import org.eclipse.team.bugs.internal.main.BugsPlugin;

public class BugProviderFactoryRegistry extends RegistryReader {

	public static final String PT_BUGPROVIDER = "bugProviderFactory"; //$NON-NLS-1$
	private static final String TAG_PROVIDER = "factory"; //$NON-NLS-1$
	
	private final Map fFactories = new HashMap();
	
	public BugProviderFactoryRegistry() {
		super();
	}

	/* (non-Javadoc)
	 * @see org.eclipse.team.internal.ui.registry.RegistryReader#readElement(org.eclipse.core.runtime.IConfigurationElement)
	 */
	protected boolean readElement(IConfigurationElement element) {
		if (element.getName().equals(TAG_PROVIDER)) {
			try {
			    final BugProviderFactoryDescription desc= new BugProviderFactoryDescription(element);
				fFactories.put(desc.getId(), desc);
			} catch (CoreException e) {
				BugsPlugin.log(e);
			}
			return true;
		}
		return false;
	}
	
	public BugProviderFactoryDescription[] getBugProviderFactories() {
		return (BugProviderFactoryDescription[])fFactories.values().toArray(new BugProviderFactoryDescription[fFactories.size()]);
	}
	
	public BugProviderFactoryDescription find(String id) {
		return (BugProviderFactoryDescription)fFactories.get(id);
	}
}
