/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugs.internal.views;

import java.util.Collection;
import java.util.Iterator;
import java.util.LinkedHashSet;

import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.team.bugs.model.IBugProvider;
import org.eclipse.team.bugs.model.IGenericModel;

/**
 * 
 */
public class BugModelSelection {
    
    private IStructuredSelection fSelection;
    private Boolean fProvidersOnly;
    private LinkedHashSet fSelectedProviders;

    public BugModelSelection() {
        super();
        setSelection(new StructuredSelection());
    }
    
    public Collection getSelectedProviders() {
        if (fSelectedProviders == null) {
            fSelectedProviders= new LinkedHashSet();
            for (final Iterator iter = fSelection.iterator(); iter.hasNext();) {
                fSelectedProviders.add(((IGenericModel)iter.next()).getProvider());
            }
        }
        return fSelectedProviders;
    }
    
    public IBugProvider getSelectedProvider() {
        return getSelectedProviders().size() == 1 ? (IBugProvider)getSelectedProviders().iterator().next() : null;
    }

    public boolean providersOnly() {
        if (fProvidersOnly == null) {
            fProvidersOnly= Boolean.TRUE;
            for (Iterator iter = fSelection.iterator(); iter.hasNext();) {
                if (!(iter.next() instanceof IBugProvider)) {
                    fProvidersOnly= Boolean.FALSE;
                    break;
                }
            }           
        }
        return fProvidersOnly.booleanValue();
    }
    
    public boolean isEmpty() {
        return fSelection.isEmpty();
    }
    
    public boolean oneElementSelected() {
        return fSelection.size() == 1;
    }
    
    public IGenericModel getSelectedElement() {
        return oneElementSelected() ? (IGenericModel)fSelection.getFirstElement() : null;
    }
    
    public Collection getSelectedElements() {
        return fSelection.toList();
    }
    
    public void setSelection(ISelection selection) {
        fSelection= (IStructuredSelection)selection;
        fSelectedProviders= null;
        fProvidersOnly= null;
    }
    
    public IStructuredSelection getSelection() {
        return fSelection;
    }
}
