/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugs.internal.views;

import java.util.HashMap;
import java.util.Map;

import org.eclipse.team.bugs.extension.BugProviderFactory;
import org.eclipse.team.bugs.extension.BugViewExtension;
import org.eclipse.team.bugs.extension.Providers;
import org.eclipse.team.bugs.model.IBugProvider;


public class BugViewExtensions {
    
    private final Map fExtensionMap;
    private final Map fProxyMap;
    private final BugView fBugView;
        
    public BugViewExtensions(BugView view) {
        fExtensionMap= new HashMap();
        fProxyMap= new HashMap();
        fBugView= view;
    }
    
    public BugViewExtension getExtension(IBugProvider provider) {
        if (!fExtensionMap.containsKey(provider)) {
            final BugProviderFactory factory= Providers.getInstance().getFactory(provider);
            final BugViewExtension extension= factory.getExtension();
            fExtensionMap.put(provider, extension);
            extension.initialize(getProxy(provider));
        }
        return (BugViewExtension)fExtensionMap.get(provider);
    }
    
    public ViewerProxy getProxy(IBugProvider provider) {
        if (!fProxyMap.containsKey(provider)) {
            final ViewerProxy proxy= new ViewerProxy(fBugView, provider);
            fProxyMap.put(provider, proxy);
        }
        return (ViewerProxy)fProxyMap.get(provider);
    }
    
    public void removeProvider(IBugProvider provider) {
        final ViewerProxy proxy= (ViewerProxy)fProxyMap.remove(provider);
        proxy.dispose();
        final BugViewExtension extension= (BugViewExtension)fExtensionMap.remove(provider);
        extension.dispose();
    }
    
    public void dispose() {
    }
}