/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugs.internal.views;

import java.util.HashMap;
import java.util.Map;

import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.SashForm;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.team.bugs.extension.BugViewExtension;
import org.eclipse.team.bugs.model.IBugProvider;
import org.eclipse.ui.part.PageBook;

class CustomControlUpdater {

    private final BugViewExtensions fExtensions;
    private final Map fCustomControls;
    private final PageBook fPageBook;
    private final Control fEmptyControl;
    
    public CustomControlUpdater(Composite parent, BugViewExtensions extensions) {
    	fPageBook= new PageBook(parent, SWT.NONE);
    	if (parent instanceof SashForm) {
    		((SashForm)parent).setWeights(new int[] { 2, 0 });
    	}
    	
    	fEmptyControl= new Composite(fPageBook, SWT.NONE);
        fCustomControls= new HashMap();
        fExtensions= extensions;
    }
    
    void update(BugModelSelection selection) {
        final IBugProvider provider= selection.getSelectedProvider();
        if (provider == null)
            return;
        if (!fCustomControls.containsKey(provider)) {
            BugViewExtension extension= fExtensions.getExtension(provider);
            fCustomControls.put(provider, extension.createCustomControl(fPageBook));
        }
        final Control control= (Control)fCustomControls.get(provider);
        fPageBook.showPage(control != null ? control : fEmptyControl);
    }
    
    void remove(IBugProvider provider) {
        fCustomControls.remove(provider);
    }
}