
package org.eclipse.team.bugs.internal.views;


import org.eclipse.jface.viewers.DoubleClickEvent;
import org.eclipse.jface.viewers.IDoubleClickListener;
import org.eclipse.jface.viewers.IOpenListener;
import org.eclipse.jface.viewers.ISelectionChangedListener;
import org.eclipse.jface.viewers.ITreeViewerListener;
import org.eclipse.jface.viewers.OpenEvent;
import org.eclipse.jface.viewers.SelectionChangedEvent;
import org.eclipse.jface.viewers.TreeExpansionEvent;
import org.eclipse.swt.events.FocusEvent;
import org.eclipse.swt.events.FocusListener;
import org.eclipse.team.bugs.model.IBugProvider;
import org.eclipse.team.bugs.model.IGenericModel;
import org.eclipse.team.bugs.model.IProviderListener;

/**
 * 
 */
class EventDispatcher implements ISelectionChangedListener, IOpenListener, IProviderListener, IDoubleClickListener, ITreeViewerListener, FocusListener {

    private final BugViewExtensions fExtensions;
    private BugModelSelection fSelection;
    
    /**
     * 
     */
    public EventDispatcher(BugViewExtensions extensions, BugModelSelection selection) {
        fExtensions= extensions;
        fSelection= selection;
    }

    /* (non-Javadoc)
     * @see org.eclipse.jface.viewers.ISelectionChangedListener#selectionChanged(org.eclipse.jface.viewers.SelectionChangedEvent)
     */
    public void selectionChanged(SelectionChangedEvent event) {
        final IBugProvider provider= fSelection.getSelectedProvider();
        if (provider == null)
            return;
        fExtensions.getProxy(provider).selectionChanged(event);
    }

    /* (non-Javadoc)
     * @see org.eclipse.jface.viewers.IOpenListener#open(org.eclipse.jface.viewers.OpenEvent)
     */
    public void open(OpenEvent event) {
        final IBugProvider provider= fSelection.getSelectedProvider();
        if (provider == null)
            return;
        fExtensions.getProxy(provider).open(event);
    }

    /* (non-Javadoc)
     * @see org.eclipse.team.bugs.model.IProviderListener#modelAdded(org.eclipse.team.bugs.model.IGenericModel, org.eclipse.team.bugs.model.IGenericModel)
     */
    public void elementsAdded(IGenericModel parent, IGenericModel[] children) {
        if (children.length == 0)
            return;
        if (parent == null) {
            // TODO: handle addition of a new provider
            return;
        }
        final IBugProvider provider= parent.getProvider();
        fExtensions.getProxy(provider).elementsAdded(parent, children);
    }

    /* (non-Javadoc)
     * @see org.eclipse.team.bugs.model.IProviderListener#modelChanged(org.eclipse.team.bugs.model.IGenericModel)
     */
    public void elementsChanged(IGenericModel[] elements) {
        if (elements.length == 0)
            return;
        final IBugProvider provider= elements[0].getProvider();
        fExtensions.getProxy(provider).elementsChanged(elements);
    }

    /* (non-Javadoc)
     * @see org.eclipse.team.bugs.model.IProviderListener#modelRemoved(org.eclipse.team.bugs.model.IGenericModel, org.eclipse.team.bugs.model.IGenericModel)
     */
    public void elementsRemoved(IGenericModel parent, IGenericModel[] children) {
        if (children.length == 0)
            return;
        if (parent == null) {
            for (int i = 0; i < children.length; i++)
                fExtensions.removeProvider((IBugProvider)children[i]);
            return;
        }
        final IBugProvider provider= parent.getProvider();
        fExtensions.getProxy(provider).elementsRemoved(parent, children);
    }

    /* (non-Javadoc)
     * @see org.eclipse.jface.viewers.IDoubleClickListener#doubleClick(org.eclipse.jface.viewers.DoubleClickEvent)
     */
    public void doubleClick(DoubleClickEvent event) {
        
    }

    /* (non-Javadoc)
     * @see org.eclipse.swt.events.TreeListener#treeCollapsed(org.eclipse.swt.events.TreeEvent)
     */
    public void treeCollapsed(TreeExpansionEvent e) {
    }

    /* (non-Javadoc)
     * @see org.eclipse.swt.events.TreeListener#treeExpanded(org.eclipse.swt.events.TreeEvent)
     */
    public void treeExpanded(TreeExpansionEvent e) {
    }

    /* (non-Javadoc)
     * @see org.eclipse.swt.events.FocusListener#focusGained(org.eclipse.swt.events.FocusEvent)
     */
    public void focusGained(FocusEvent e) {
        final IBugProvider provider= fSelection.getSelectedProvider();
        if (provider == null)
            return;
        fExtensions.getProxy(provider).focusGained(e);
    }

    /* (non-Javadoc)
     * @see org.eclipse.swt.events.FocusListener#focusLost(org.eclipse.swt.events.FocusEvent)
     */
    public void focusLost(FocusEvent e) {
        final IBugProvider provider= fSelection.getSelectedProvider();
        if (provider == null)
            return;
        fExtensions.getProxy(provider).focusLost(e);
    }

}
