/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugs.internal.views;

import org.eclipse.swt.widgets.Tree;
import org.eclipse.team.bugs.extension.Providers;
import org.eclipse.team.bugs.model.IGenericModel;
import org.eclipse.team.bugs.model.IProviderListener;


class TreeManager implements IProviderListener {
    
    private BugView fView;
    private Tree fTree;

    public TreeManager(BugView view) {
        fView= view;
        fTree= view.getViewer().getTree();
    }

    public void elementsAdded(IGenericModel parent, IGenericModel[] children) {
        fTree.setRedraw(false);
        try {
            fView.getViewer().refresh(parent != null ? parent : (Object)Providers.getInstance());
        } finally {
			if (parent != null) {
				fView.getViewer().setExpandedState(parent.getProvider(), true);
			}
			fTree.setRedraw(true);
        }
    }

    public void elementsChanged(IGenericModel[] elements) {
        try {
            for (int i = 0; i < elements.length; i++) {
                fView.getViewer().update(elements[i], null);
            }
        } finally {
			fView.getViewer().setExpandedState(elements[0].getProvider(), true);
            fTree.setRedraw(true);
        }
    }

    public void elementsRemoved(IGenericModel parent, IGenericModel[] children) {
        fTree.setRedraw(false);
        try {
            fView.getViewer().refresh( parent != null ? parent : (Object)Providers.getInstance());
        } finally {
            fTree.setRedraw(true);
        }
    }
}