package org.eclipse.team.bugzilla;

import java.net.URL;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IPath;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Path;
import org.eclipse.core.runtime.Status;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.jface.resource.ImageRegistry;
import org.eclipse.swt.graphics.Image;
import org.eclipse.team.bugs.extension.BugsException;
import org.eclipse.ui.plugin.AbstractUIPlugin;
import org.osgi.framework.BundleContext;

/**
 * The main plugin class to be used in the desktop.
 */
public class BugzillaPlugin extends AbstractUIPlugin {
    
    /**
     * Image keys
     */
    public static final String IMG_BUGZILLA= "bugzilla"; //$NON-NLS-1$
    
	/**
	 * The shared instance.
	 */
	private static BugzillaPlugin plugin;
	
	/**
	 * Resource bundle.
	 */
	private ResourceBundle resourceBundle;
	
	/**
	 * The plug-in's id
	 */
	public static final String ID = "org.eclipse.team.bugzilla"; //$NON-NLS-1$
	
	public static void log(IStatus status) {
		getDefault().getLog().log(status);
		
	}

	public static void log(CoreException e) {
		log(e.getMessage(), e);
	}

	public static void log(String string, CoreException e) {
	    int code = 0;
	    if (e != null)
	        code = e.getStatus().getCode();
        log(new Status(IStatus.ERROR, ID, code, string, e));
	}
	
	/**
	 * The constructor.
	 */
	public BugzillaPlugin() {
		super();
		plugin = this;
	}

	/**
	 * This method is called upon plug-in activation
	 */
	public void start(BundleContext context) throws Exception {
		super.start(context);
	}

	/**
	 * This method is called when the plug-in is stopped
	 */
	public void stop(BundleContext context) throws Exception {
		super.stop(context);
	}

	/**
	 * Returns the shared instance.
	 */ 
	public static BugzillaPlugin getDefault() {
		return plugin;
	}

	/**
	 * Returns the string from the plugin's resource bundle,
	 * or 'key' if not found.
	 */
	public static String getResourceString(String key) {
		ResourceBundle bundle = BugzillaPlugin.getDefault().getResourceBundle();
		try {
			return (bundle != null) ? bundle.getString(key) : key;
		} catch (MissingResourceException e) {
			return key;
		}
	}

	/**
	 * Returns the plugin's resource bundle,
	 */
	public ResourceBundle getResourceBundle() {
		try {
			if (resourceBundle == null)
				resourceBundle = ResourceBundle.getBundle("org.eclipse.team.bugzilla.BugzillaPluginResources");
		} catch (MissingResourceException x) {
			resourceBundle = null;
		}
		return resourceBundle;
	}

	/**
	 * Log a BugsException.
	 * @param e The exception to log
	 */
	 public static void log(BugzillaException e) {
	     getDefault().getLog().log(e.getStatus());
	 }

	 /* (non-Javadoc)
	 * @see org.eclipse.ui.plugin.AbstractUIPlugin#initializeImageRegistry(org.eclipse.jface.resource.ImageRegistry)
	 */
	protected void initializeImageRegistry(ImageRegistry registry) {
	     registerImage(registry, IMG_BUGZILLA, "bugzilla.gif"); //$NON-NLS-1$
	 }
	 
	 /**
	  * Register the image.
	  * 
	  * @param registry The image registry.
	  * @param key The key.
	  * @param fileName The file name.
	  */
	 private void registerImage(ImageRegistry registry, String key, String fileName) {
	     try {
	         IPath path = new Path("icons/" + fileName); //$NON-NLS-1$
	         URL url = find(path);
	         if (url != null) {
	             ImageDescriptor desc = ImageDescriptor.createFromURL(url);
	             registry.put(key, desc);
	         }
	     } catch (Exception e) {
	         final IStatus status= new Status(IStatus.ERROR, ID, 0, e.getMessage(), e);
	         log(new BugsException(status));
	     }
	 }
	 
	 /**
	  * Get the image.
	  * 
	  * @param key The key.
	  * @return The image.
	  */
	 public Image getImage(String key) {
	     return getImageRegistry().get(key);
	 }

    /**
     * @param string
     * @param targetException
     */
    public static void log(String string, Throwable targetException) {
        if (targetException instanceof CoreException) {
            log(string, (CoreException)targetException);
        } else {
            log(new Status(IStatus.ERROR, ID, 0, string, targetException));
        }
    }
}
