/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.team.bugzilla;

import java.lang.reflect.InvocationTargetException;

import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.jface.dialogs.ErrorDialog;
import org.eclipse.ui.IWorkbenchPart;

public class Util {

    public static final String URL_SEPARATOR = "/"; //$NON-NLS-1$
    
	public static String appendPath(String prefix, String suffix) {
	    if (suffix.startsWith(prefix)) return suffix;
		if (prefix.endsWith(URL_SEPARATOR)) {
		    return prefix + (suffix.startsWith(URL_SEPARATOR) ? suffix.substring(1) : suffix);
		} else if (suffix.startsWith(URL_SEPARATOR))
			return prefix + suffix;
		else
			return prefix + URL_SEPARATOR + suffix;
	}

    /**
     * Convert the given string to a valid path segment.
     * A valid path segment doies not contain any
     * forward slashes.
     * @param string the string
     * @return the string converted to a valid path segment
     */
    public static String asValidPathSegment(String string) {
        return string.replace('/', '.');
    }

    /**
     * Return the path as a valid relative path
     * @param path the path
     * @return the path as a relative path
     */
    public static String asRelativePath(String path) {
        if (path.startsWith(URL_SEPARATOR)) {
            path = path.substring(1);
        }
        if (!path.endsWith(URL_SEPARATOR)) {
            path += URL_SEPARATOR;
        }
        return path;
    }

    /**
     * @param part
     * @param e
     */
    public static void handleError(IWorkbenchPart part, Throwable e) {
        //TODO: We're a little bit verbose at the moment, we should give visual indications for errors.
        if (e instanceof InvocationTargetException) {
            handleError(part, ((InvocationTargetException)e).getTargetException());
        } else if (e instanceof BugzillaException) {
            
            final IStatus status= ((BugzillaException)e).getStatus();
            
            
            switch (status.getCode()) {
            case BugzillaException.IO_ERROR:
            case BugzillaException.UNEXPECTED_CONDITION:
            case BugzillaException.REQUIRES_LOGIN:
            case BugzillaException.MULTI_ERROR:
                ErrorDialog.openError(part.getSite().getShell(), null, null, status);
            case BugzillaException.XML_ERROR: 
            case BugzillaException.PERSISTENCE_READ_ERROR:
                BugzillaPlugin.log((BugzillaException)e);          
            }
        } else if (e instanceof CoreException) {
            ErrorDialog.openError(part.getSite().getShell(), null, null, ((CoreException)e).getStatus());
        } else {      
	        ErrorDialog.openError(part.getSite().getShell(), null, null, new Status(IStatus.ERROR, BugzillaPlugin.ID, 0, "Internal error", e));
        } 
    }
	
}
