/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugzilla.actions;


import java.lang.reflect.InvocationTargetException;

import org.eclipse.core.runtime.CoreException;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.window.Window;
import org.eclipse.team.bugzilla.dialogs.NewBugDialog;
import org.eclipse.team.bugzilla.model.BugzillaContainer;
import org.eclipse.team.bugzilla.model.BugzillaModel;
import org.eclipse.team.bugzilla.model.BugzillaReport;
import org.eclipse.team.bugzilla.model.IRemoteModel;
import org.eclipse.team.bugzilla.operations.RefreshOperation;
import org.eclipse.ui.IViewActionDelegate;

/**
 * 
 */
public class AddBugReportAction extends BugzillaActionDelegate implements IViewActionDelegate {

    public void run(IAction action) {
        
        final BugzillaContainer container= getSelectedContainer();

        final NewBugDialog dialog= new NewBugDialog(getTargetPart().getSite().getShell());
        
        dialog.open();
        
        if (dialog.getReturnCode() == Window.CANCEL)
            return;

        // If the report already exists, refresh it.
        // Otherwise create and refresh it.
        String id = dialog.getID();
        BugzillaReport report = getReport(container, id);
        if (report == null)
            report= new BugzillaReport(container, id);
        try {
            new RefreshOperation(getTargetPart(), new IRemoteModel[] { report }).run();
        } catch (InvocationTargetException e) {
            handleError(e);
        } catch (InterruptedException e) {
            // Ignore
        }
    }

    private BugzillaReport getReport(BugzillaContainer container, String id) {
        BugzillaModel[] children = container.getChildren();
        for (int i = 0; i < children.length; i++) {
            BugzillaModel model = children[i];
            if (model instanceof BugzillaReport) {
                if (id.equals(((BugzillaReport)model).getID())) {
                    return (BugzillaReport)model;
                }
            }
        }
        return null;
    }

    /* (non-Javadoc)
     * @see org.eclipse.team.bugzilla.actions.BugzillaActionDelegate#isEnabled()
     */
    protected boolean isEnabled() throws CoreException {
        final BugzillaContainer container= getSelectedContainer();
        if (container == null)
            return false;
        return container.canModifyChildren();
    }
}
