/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.team.bugzilla.actions;

import org.eclipse.jface.action.Action;
import org.eclipse.jface.util.Assert;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.team.bugs.extension.IViewerProxy;
import org.eclipse.team.bugzilla.tools.BugzillaSelection;
import org.eclipse.team.bugzilla.tools.IBugzillaSelectionProvider;
import org.eclipse.ui.IWorkbenchPart;

/**
 * Abstract superclass of the bugzilla actions.
 */
public abstract class BugzillaAction extends Action {

    private final IViewerProxy fProxy;
    private final IBugzillaSelectionProvider fSelectionProvider;

    public BugzillaAction(String name, IViewerProxy proxy, IBugzillaSelectionProvider selectionProvider) {
        super(name);
        Assert.isNotNull(proxy);
        Assert.isNotNull(selectionProvider);
        fProxy= proxy;
        fSelectionProvider= selectionProvider;
    }
    
    public abstract void setEnablement();
    
    protected final  Shell getShell() {
        return fProxy.getPart().getSite().getShell();
    }
    
    protected IWorkbenchPart getPart() {
        return fProxy.getPart();
    }
    
    protected IViewerProxy getProxy() {
        return fProxy;
    }
    
    protected BugzillaSelection getSelection() {
        return fSelectionProvider.getSelection();
    }
}
