/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugzilla.actions;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.swt.dnd.TextTransfer;
import org.eclipse.swt.dnd.Transfer;
import org.eclipse.team.bugs.extension.IViewerProxy;
import org.eclipse.team.bugzilla.tools.BugzillaSelection;
import org.eclipse.team.bugzilla.tools.IBugzillaSelectionProvider;
import org.eclipse.team.bugzilla.view.BugzillaTransfer;
import org.eclipse.team.bugzilla.view.BugzillaViewExtension;
import org.eclipse.team.bugzilla.view.TextPane;

/**
 * 
 */
public class BugzillaCopyAction extends BugzillaAction {
    
    private final BugzillaPasteAction fPasteAction;
    private BugzillaViewExtension fExtension;
    
    public BugzillaCopyAction(IViewerProxy proxy, BugzillaViewExtension extension, BugzillaPasteAction pasteAction) {
        super("Copy", proxy, extension.getBugzillaSelectionProvider());
        fPasteAction= pasteAction;
        fExtension= extension;
    }
    
    public void run() {

        final List content= new ArrayList();
        final List transfers= new ArrayList();
        
        getBugzillaSelection(content, transfers);
        getTextSelection(content, transfers);

        getProxy().getClipboard().setContents(content.toArray(), (Transfer[])transfers.toArray(new Transfer [transfers.size()]));
        fPasteAction.setEnablement();
    }
    
    private void getBugzillaSelection(List content, List transfers) {
        final IBugzillaSelectionProvider provider= fExtension.getBugzillaSelectionProvider();
        if (provider == null || !getProxy().getViewer().getControl().isFocusControl())
            return;
        final BugzillaSelection selection= getValidatedSelection();
        if (selection == null)
            return;
        content.add(selection.toBugzillaArray());
        transfers.add(BugzillaTransfer.getInstance());
    }
    
    private void getTextSelection(List content, List transfers) {
        final TextPane textPane= fExtension.getTextPane();
        if (textPane == null || textPane.getStyledText() == null || !textPane.getStyledText().isFocusControl())
            return;
        final String selection= textPane.getStyledText().getSelectionText();
        content.add(selection);
        transfers.add(TextTransfer.getInstance());
    }
    
    private BugzillaSelection getValidatedSelection() {
        final BugzillaSelection selection= getSelection();
        if (selection.isEmpty() || selection.getCommonParent() == null)
            return null;
        return selection;
    }
    
    

    /* (non-Javadoc)
     * @see org.eclipse.team.bugzilla.actions.BugzillaAction#setEnablement()
     */
    public void setEnablement() {
        final List content= new ArrayList();
        final List transfers= new ArrayList();
        
        getBugzillaSelection(content, transfers);
        getTextSelection(content, transfers);

        setEnabled(content.size() > 0 && transfers.size() > 0);
    }
}
