/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugzilla.actions;

import org.eclipse.team.bugs.extension.IViewerProxy;
import org.eclipse.team.bugzilla.model.BugzillaContainer;
import org.eclipse.team.bugzilla.tools.BugzillaSelection;
import org.eclipse.team.bugzilla.tools.IBugzillaSelectionProvider;

/**
 * 
 */
public class BugzillaDeleteAction extends BugzillaAction {
    
    public BugzillaDeleteAction(IViewerProxy proxy, IBugzillaSelectionProvider provider) {
        super("Delete", proxy, provider);
    }
    
    public void run() {
        final BugzillaSelection selection= getValidatedSelection();
        if (selection == null)
            return;
        selection.getCommonParent().removeChildren(selection.toBugzillaArray());
    }
    
    private BugzillaSelection getValidatedSelection() {
        
		final BugzillaSelection selection= getSelection();
		
        final BugzillaContainer parent= selection.getCommonParent();
        
        if (parent == null || !parent.canModifyChildren())
            return null;
        
        if (selection.containsReadOnlyElements())
            return null;
        
        return selection;
    }
    
    /* (non-Javadoc)
     * @see org.eclipse.team.bugzilla.actions.BugzillaAction#setEnablement()
     */
    public void setEnablement() {
        setEnabled(getValidatedSelection() != null);
    }
}
