/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugzilla.actions;

import org.eclipse.jface.window.Window;
import org.eclipse.team.bugs.extension.IViewerProxy;
import org.eclipse.team.bugzilla.dialogs.FolderNameDialog;
import org.eclipse.team.bugzilla.model.BugzillaContainer;
import org.eclipse.team.bugzilla.model.BugzillaFolder;
import org.eclipse.team.bugzilla.model.BugzillaModel;
import org.eclipse.team.bugzilla.model.BugzillaQuery;
import org.eclipse.team.bugzilla.tools.BugzillaSelection;
import org.eclipse.team.bugzilla.tools.IBugzillaSelectionProvider;

/**
 * Rename global action handler for bugzilla
 */
public class BugzillaRenameAction extends BugzillaAction {
    
    public BugzillaRenameAction(IViewerProxy proxy, IBugzillaSelectionProvider provider) {
        super("Rename...", proxy, provider);
    }
    
    public void run() {
        BugzillaModel element = getElementToRename();
        if (element != null) {
            if (element instanceof BugzillaFolder) {
                if (!renameFolder((BugzillaFolder)element)) return;
            } else if (element instanceof BugzillaQuery) {
                if (!renameQuery((BugzillaQuery)element)) return;
            }
        }
    }

    private boolean renameFolder(BugzillaFolder folder) {
        final BugzillaContainer parent= (BugzillaContainer)folder.getParent();
        
        final FolderNameDialog dialog= new FolderNameDialog(getShell(), parent, "Rename Folder", "Folder name:", folder.getName());
        dialog.open();
        
        if (dialog.getReturnCode() != Window.OK)
            return false;
        
        String name = dialog.getName();
        if (name.equals(folder.getName()))
            return false;
        
        renameFolder(folder, name);
        return true;
    }

    private void renameFolder(BugzillaFolder folder, String name) {
        final BugzillaContainer parent= (BugzillaContainer)folder.getParent();
        // Create a new folder
        final BugzillaFolder target = new BugzillaFolder(parent, name);
        // Copy the children of the old folder to the new folder
        final BugzillaModel [] children = folder.getChildren();
        folder.removeChildren(children);
        target.addChildren(children);
        parent.removeChildren(new BugzillaModel [] { folder });
    }

    private boolean renameQuery(BugzillaQuery query) {
        final BugzillaContainer parent= (BugzillaContainer)query.getParent();
        
        final FolderNameDialog dialog= new FolderNameDialog(getShell(), parent, "Rename Query", "Query name:", query.getName());
        dialog.open();
        
        if (dialog.getReturnCode() != Window.OK)
            return false;
        
        String name = dialog.getName();
        if (name.equals(query.getName()))
            return false;
        
        query.setName(name);
        return true;
    }
    
    private BugzillaModel getElementToRename() {
        final BugzillaSelection selection= getSelection();
        
		if (selection.size() != 1)
		    return null;
		
		if (selection.containsReadOnlyElements())
		    return null;
		
		final BugzillaContainer parent= selection.getCommonParent();
		
		if (parent == null)
		    return null;
		
		if (!parent.canModifyChildren())
		    return null;
		
		return (BugzillaModel)selection.getFirstElement();
    }
    
    /* (non-Javadoc)
     * @see org.eclipse.team.bugzilla.actions.BugzillaAction#setEnablement()
     */
    public void setEnablement() {
        setEnabled(getElementToRename() != null);
    }
}
