/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.team.bugzilla.actions;

import java.io.BufferedInputStream;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;

import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.Platform;
import org.eclipse.core.runtime.preferences.IPreferencesService;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.ErrorDialog;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.swt.widgets.FileDialog;

/**
 * Import a previously exported container
 */
public class ImportAction extends BugzillaActionDelegate {

    /* (non-Javadoc)
     * @see org.eclipse.team.bugzilla.actions.BugzillaActionDelegate#isEnabled()
     */
    protected boolean isEnabled() throws CoreException {
        return getSelectedContainer() != null;
    }
    
    /* (non-Javadoc)
     * @see org.eclipse.ui.actions.ActionDelegate#run(org.eclipse.jface.action.IAction)
     */
    public void run(IAction action) {
        FileDialog dialog = new FileDialog(getTargetPart().getSite().getShell());
        String filename = dialog.open();
        InputStream input = null;
        try {
            input = new BufferedInputStream(new FileInputStream(filename));
            verifyVersion(input);
            IPreferencesService service = Platform.getPreferencesService();
            if (MessageDialog.openQuestion(getTargetPart().getSite().getShell(), "Overwrite?", "Importing may overwrite existing elements. Continue?")) {
                service.importPreferences(input);
            }
            // TODO: Would need to rebuild the model as well which is more work than I want to do now
        } catch (IOException e) {
            ErrorDialog.openError(getTargetPart().getSite().getShell(), null, e.getMessage(), null);
        } catch (CoreException e) {
            ErrorDialog.openError(getTargetPart().getSite().getShell(), null, null, e.getStatus());
        } finally {
            try {
                if (input != null)
                    input.close();
            } catch (IOException e1) {
                // Ignore
            }
        }
    }

    private void verifyVersion(InputStream input) throws IOException {
        int next = input.read();
        StringBuffer version = new StringBuffer();
        while(next != -1 && next != '\n') {
            version.append((char)next);
            next = input.read();
        }
        if (next == -1 || !version.toString().trim().equals(ExportAction.VERSION_1))
            throw new IOException("File is not a valid bugzilla model file");
    }

}
