/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugzilla.actions;
import java.lang.reflect.InvocationTargetException;
import java.util.ArrayList;
import java.util.List;

import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.team.bugs.extension.BugsImages;
import org.eclipse.team.bugs.extension.IViewerProxy;
import org.eclipse.team.bugzilla.Util;
import org.eclipse.team.bugzilla.model.BugzillaModel;
import org.eclipse.team.bugzilla.model.BugzillaProvider;
import org.eclipse.team.bugzilla.model.IRemoteModel;
import org.eclipse.team.bugzilla.operations.RefreshOperation;
import org.eclipse.team.bugzilla.tools.BugzillaSelection;
import org.eclipse.team.bugzilla.tools.IBugzillaSelectionProvider;


public class RefreshAction extends BugzillaAction {
     
    public RefreshAction(IViewerProxy proxy, IBugzillaSelectionProvider provider) {
        super("Refresh", proxy, provider);
    }
    
    public void run() {

        final IRemoteModel[] elements= getRemoteModels();
        if (elements.length == 0) {
        	((BugzillaProvider)(getSelection().getOnlyElement())).getDataCache().refreshQueryOptions();
        	return;
        }
        
        try {
            new RefreshOperation(getPart(), elements).run();
        } catch (InvocationTargetException e) {
            Util.handleError(getPart(), e);
        } catch (InterruptedException e) {
            // ignore
        }
    }
    
    public ImageDescriptor getImageDescriptor() {
        return BugsImages.REFRESH;
    }

    private IRemoteModel [] getRemoteModels() {
        
        final BugzillaSelection selection= getSelection();
        
        final List remoteModels= new ArrayList();
        final BugzillaModel [] elements= selection.toBugzillaArray();
        for (int i = 0; i < elements.length; i++) {
	        if (elements[i] instanceof IRemoteModel) { 
		        remoteModels.add(elements[i]);
	        }
        }
        return (IRemoteModel[]) remoteModels.toArray(new IRemoteModel[remoteModels.size()]);
    }
    
    /* (non-Javadoc)
     * @see org.eclipse.team.bugzilla.actions.BugzillaAction#setEnablement()
     */
    public void setEnablement() {
        setEnabled(getRemoteModels().length > 0 || getSelection().getOnlyElement() instanceof BugzillaProvider);
    }
}