/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.team.bugzilla.adapters;

import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.swt.graphics.FontData;
import org.eclipse.team.bugzilla.BugzillaImages;
import org.eclipse.team.bugzilla.browser.IWebContentAdapter;
import org.eclipse.team.bugzilla.model.BugzillaQuery;

public class BugzillaQueryAdapter extends ContainerAdapter implements IWebContentAdapter/*, IPresentableAdapter*/ {

    /* (non-Javadoc)
     * @see org.eclipse.ui.model.IWorkbenchAdapter#getImageDescriptor(java.lang.Object)
     */
    protected ImageDescriptor doGetImageDescriptor(Object object) {
        return BugzillaImages.QUERY;
    }

    /* (non-Javadoc)
     * @see org.eclipse.team.bugzilla.browser.IWebContentAdapter#getURL(java.lang.Object)
     */
    public String getURL(Object o) {
        if (o instanceof BugzillaQuery) {
            return ((BugzillaQuery)o).getQueryUrl().toUrlString();
        }
        return null;
    }
    
    /* (non-Javadoc)
     * @see org.eclipse.team.bugzilla.adapters.ContainerAdapter#getLabel(java.lang.Object)
     */
    public String getLabel(Object o) {
       final BugzillaQuery query= (BugzillaQuery)o;
       return query.isRefreshing() ? getRefreshingLabel("query " + query.getName()) : getStandardLabel(query);
    }

    /**
     * @param query
     * @return String
     */
    private String getStandardLabel(final BugzillaQuery query) {
        final StringBuffer label= new StringBuffer();
           if (query.hasLocalContent()) {
               label.append("(");
               final int size= query.getChildren().length;
               label.append(size).append(size == 1 ? " result" : " results").append(") ");
           }
           return label.append(query.getName()).toString();
    }
    
    /* (non-Javadoc)
     * @see org.eclipse.team.bugzilla.adapters.ModelElementAdapter#getFont(java.lang.Object)
     */
    public FontData getFont(Object element) {
        final BugzillaQuery query= (BugzillaQuery)element;
        if (query.isRefreshing())
            return getRefreshingFont();
        return super.getFont(element);
    }
    /*
    public void present(Object presentable, StyledText styledText) {
    	
    	if (!(presentable instanceof BugzillaQuery)) 
            return;
    	
    	new BugzillaModelPresenter().present((BugzillaQuery)presentable, styledText);
    	
     }
     */
}
