/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugzilla.adapters;

import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.swt.custom.StyledText;
import org.eclipse.swt.graphics.FontData;
import org.eclipse.swt.graphics.RGB;
import org.eclipse.team.bugzilla.BugzillaImages;
import org.eclipse.team.bugzilla.browser.IWebContentAdapter;
import org.eclipse.team.bugzilla.datatypes.ReportData;
import org.eclipse.team.bugzilla.model.BugzillaProvider;
import org.eclipse.team.bugzilla.model.BugzillaReport;
import org.eclipse.team.bugzilla.operations.CachedOperations;
import org.eclipse.team.bugzilla.view.BugzillaModelPresenter;
import org.eclipse.team.bugzilla.view.IPresentableAdapter;

/**
 * 
 */
public class BugzillaReportAdapter extends ModelElementAdapter implements IPresentableAdapter, IWebContentAdapter {


    public void present(Object presentable, StyledText styledText) {

        if (!(presentable instanceof BugzillaReport)) 
            return;
        
        new BugzillaModelPresenter().present((BugzillaReport)presentable, styledText);
    }

    public Object[] getChildren(Object o) {
        return ((BugzillaReport)o).getComments().toArray();
    }

    protected ImageDescriptor doGetImageDescriptor(Object object) {
        final BugzillaReport report= (BugzillaReport)object;
        final ReportData data= report.getReportData();
        return data != null ? BugzillaImages.BUG : BugzillaImages.INCOMPLETE_BUG;
    }

    public String getLabel(Object o) {
        final BugzillaReport report= (BugzillaReport)o;
        return report.isRefreshing() ? getRefreshingLabel("bug " + report.getID()) : getStandardLabel(report);
    }
    
    /**
     * @param report
     * @return String
     */
    private String getStandardLabel(final BugzillaReport report) {
        final StringBuffer name= new StringBuffer();
        name.append(report.getID());
        
        final ReportData data= report.getReportData();
        
        if (data != null) {
            final String priority= data.getString(ReportData.PRIORITY);
            final String status= data.getString(ReportData.STATUS);
            final String milestone= data.getString(ReportData.TARGETMILESTONE);
            final String title= data.getString(ReportData.TITLE);
            
            name.append(" [");
            if (priority != null) name.append(priority);
            if (status != null) name.append(" ").append(status);
            if (milestone != null) name.append(" ").append(milestone);
            name.append("]");
            if (title != null) name.append(" ").append(title);
        }
        return name.toString();
    }

    public String getURL(Object o) {
        final BugzillaReport report= (BugzillaReport)o;
        final BugzillaProvider provider= (BugzillaProvider)report.getProvider();
        final CachedOperations operations= provider.getOperations();
        if (operations.isCached()) {
            return operations.getOperations().getReportURL(provider.getConfiguration(), report.getID());
        }
        return null;
    }

    /* (non-Javadoc)
     * @see org.eclipse.ui.model.IWorkbenchAdapter2#getForeground(java.lang.Object)
     */
    public RGB getForeground(Object element) {
        final ReportData data= ((BugzillaReport)element).getReportData();
        
        if (data == null)
            return super.getForeground(element);
        
        final String severity= data.getString(ReportData.SEVERITY);
        
        if ("blocker".equals(severity) || "critical".equals(severity)) {
            return RED;
        }
        return super.getForeground(element);
    }

    /* (non-Javadoc)
     * @see org.eclipse.ui.model.IWorkbenchAdapter2#getFont(java.lang.Object)
     */
    public FontData getFont(Object element) {
        
        final BugzillaReport report= (BugzillaReport)element;
        if (report.isRefreshing())
            return getRefreshingFont();
        
        final ReportData data= report.getReportData();
        
        if (data == null)
            return super.getFont(element);

        final String severity= data.getString(ReportData.SEVERITY);
        
        if ("enhancement".equals(severity)) {
            return ITALIC_FONT;
        }
        
        if ("blocker".equals(severity)) {
            return BOLD_FONT;
        }
        
        return super.getFont(element);
    }
    
}
