package org.eclipse.team.bugzilla.datatypes;

import java.io.UnsupportedEncodingException;
import java.lang.String;
import java.net.URLEncoder;
import java.util.Map;
import java.util.HashMap;
import java.util.Set;
import java.util.Iterator;

/*
 * A class to represent a bugzilla transaction via a URL
 */
public class BugzillaTransactionURL {
	
	protected String url;       // the URL of the bugzilla data-base
	protected String transUrl; 	// the complete transaction URL
	protected String script;    // the name of the (.cgi) script for this action
	protected Map params; // maps parameter field names to values
	
	// initialize URL and member vars
	public BugzillaTransactionURL(String url) { 
		setURL(url);
		script = "";
		transUrl = "";
		params = new HashMap();
	}
	
	// set the URL for the bugzilla transaction
	public void setURL(String url) { 
		this.url = url; 
		
		if(!this.url.endsWith("/"))
			this.url += "/";
	}
	
	// set the (.cgi) script name
	public void setScriptName(String s) {
		script = s;
	}
	
	// returns the most recent transaction generated
	public String getTransactionString() {
		return transUrl;
	}
	
	// generate the action string (.cgi style) from the parameters set by addActionParam() and set*() (or init())
	protected String generateTransactionString() {
		
		if(url.equals("")) {
			System.err.println("BugzillaTransactionURL: No URL defined for transaction");
			return url;
		}
		
		transUrl = url + script;
		Iterator fieldIter = ((Set)params.keySet()).iterator();
		
		try {
			while(fieldIter.hasNext()) {
				String field = (String)fieldIter.next();
				transUrl += "&" + field + "=" + URLEncoder.encode((String)params.get(field), "UTF-8");
				
			}
		} catch (UnsupportedEncodingException e) {
			e.printStackTrace();
		}
		
		return transUrl;
	}
	
	// add the specified 'field' to 'value' mapping
	public void addTransactionParam(String field, String value) {
		if ( (value == null || field == null) ||
			 (value.trim().equals("") || field.trim().equals("")) ) {
			return;
		}
		
		params.put(field, value);
	}
	
}
