/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugzilla.datatypes;

import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Collection;
import java.util.Date;
import java.util.HashMap;

/**
 * 
 */
public abstract class Data {
    
    private final static DateFormat sDateFormat= new SimpleDateFormat("yyyy-MM-dd HH:mm"); //$NON-NLS-1$
    
    private final HashMap fValues;
    private final HashMap fChangedValues;

    public Data() {
        fValues= new HashMap();
        fChangedValues= new HashMap();
    }

    public void set(String key, String value) {
        if (!getKeys().contains(key))
            return;
        
        final String oldValue= (String)fValues.get(key);
        if (oldValue == null) {
            fValues.put(key, value);
            fChangedValues.remove(key);
        } else if (!oldValue.equals(value)) {
            fChangedValues.put(key, value);
        }
    }

    public void set(String key, Date date) {
        set(key, sDateFormat.format(date));
    }
    
    public void set(String key, boolean state) {
        set(key, Boolean.valueOf(state).toString());
    }
    
    public String getString(String key) {
        if (fChangedValues.containsKey(key))
            return (String)fChangedValues.get(key);
        return (String)fValues.get(key);
    }
    
    public Date getDate(String key) {
        try {
            return sDateFormat.parse((String)fValues.get(key));
        } catch (ParseException e) {
            return null; // should not happen!
        }
    }
    
    public boolean getBoolean(String key) {
        return Boolean.valueOf(getString(key)).booleanValue();
    }
    
    public boolean hasChanged(String key) {
        return fChangedValues.containsKey(key);        
    }
    
    public boolean exists(String key) {
        return fValues.containsKey(key);
    }
    
    public void commitChanged() {
        fValues.putAll(fChangedValues);
    }
    
    public void commitChanged(String key) {
        if (fChangedValues.containsKey(key)) {
            fValues.put(key, fChangedValues.get(key));
        }
    }
    
    /**
     * Clients must implement this to define the set of keys which are allowed. Iteration and lookup 
     * should be fast, so a LinkedHashSet may be a good choice. 
     * @return Collection
     */
    protected abstract Collection getKeys();
}
