/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugzilla.datatypes;


import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.LinkedHashSet;
import java.util.List;

public class ReportData extends Data {
    
    public final static String ID= "0";
    public final static String STATUS= "1";
    public final static String PRODUCT= "2";
    public final static String PRIORITY= "3";
    public final static String VERSION= "4";
    public final static String PLATFORM= "5";
    public final static String ASSIGNEDTO= "6";
    public final static String DELTATIMESTAMP= "7";
    public final static String COMPONENT= "8";
    public final static String TARGETMILESTONE= "9";
    public final static String SEVERITY= "A";
    public final static String QACONTACT= "B";
    public final static String OPERATINGSYSTEM= "C";
    public final static String RESOLUTION= "D";
    public final static String BUGFILELOCATION= "E";
    public final static String STATUSWHITEBOARD= "F";
    public final static String TITLE= "G";
    public final static String BUGZILLAVERSION= "H";
    
    private final static LinkedHashSet sSet;
    
    static {
        sSet= new LinkedHashSet();
        sSet.add(BUGZILLAVERSION);
        sSet.add(ID);
        sSet.add(STATUS);
        sSet.add(PRODUCT);
        sSet.add(PRIORITY);
        sSet.add(VERSION);
        sSet.add(PLATFORM);
        sSet.add(ASSIGNEDTO);
        sSet.add(DELTATIMESTAMP);
        sSet.add(COMPONENT);
        sSet.add(TARGETMILESTONE);
        sSet.add(SEVERITY);
        sSet.add(QACONTACT);
        sSet.add(OPERATINGSYSTEM);
        sSet.add(RESOLUTION);
        sSet.add(BUGFILELOCATION);
        sSet.add(STATUSWHITEBOARD);
        sSet.add(TITLE);
    }
    
    public List keywords;
    public List dependsOn;
    public List blocks;
    public List ccs;
    public List comments;
    
    public ReportData() {
        super();
        keywords= new ArrayList();
        dependsOn= new ArrayList();
        blocks= new ArrayList();
        ccs= new ArrayList();
        comments= new ArrayList();
    }
    
    
    public String toString() {
        
        final StringBuffer buffer= new StringBuffer();
        final String nl= System.getProperty("line.separator"); //$NON-NLS-1$
        final String space= " "; //$NON-NLS-1$
        
        buffer.append("ID: " + getString(ID) + nl); //$NON-NLS-1$
        buffer.append("Status: " + getString(STATUS) + nl); //$NON-NLS-1$
        buffer.append("Product: " + getString(PRODUCT) + nl); //$NON-NLS-1$
        buffer.append("Priority: " + getString(PRIORITY) + nl); //$NON-NLS-1$
        buffer.append("Version: " + getString(VERSION) + nl); //$NON-NLS-1$
        buffer.append("Platform: " + getString(PLATFORM) + nl); //$NON-NLS-1$
        buffer.append("Assigned To: " + getString(ASSIGNEDTO) + nl); //$NON-NLS-1$
        buffer.append("Delta Time Stamp: " + getString(DELTATIMESTAMP) + nl); //$NON-NLS-1$
        buffer.append("Component: " + getString(COMPONENT) + nl); //$NON-NLS-1$
        buffer.append("Target Milestone: " + getString(TARGETMILESTONE) + nl); //$NON-NLS-1$
        buffer.append("Severity: " + getString(SEVERITY) + nl); //$NON-NLS-1$
        buffer.append("Operating System: " + getString(OPERATINGSYSTEM) + nl); //$NON-NLS-1$
        
        buffer.append("Keywords:"); //$NON-NLS-1$
        for (Iterator iter = keywords.iterator(); iter.hasNext();) {
            buffer.append(space + iter.next());
        }

        buffer.append(nl + "Depends On:"); //$NON-NLS-1$
        for (Iterator iter = dependsOn.iterator(); iter.hasNext();) {
            buffer.append(space + iter.next());
        }
        
        buffer.append(nl + "Blocks:"); //$NON-NLS-1$
        for (Iterator iter = blocks.iterator(); iter.hasNext(); ) {
            buffer.append(space + iter.next());
        }

        buffer.append(nl + "CCs:"); //$NON-NLS-1$
        for (Iterator iter = ccs.iterator(); iter.hasNext(); ) {
            buffer.append(space + iter.next());
        }
        
        buffer.append(nl + "Comments: "); //$NON-NLS-1$
        for (Iterator iter = comments.iterator(); iter.hasNext(); ) {
            buffer.append(space + iter.next());
        }
        return buffer.append(nl).toString();
    }

    protected Collection getKeys() {
        return sSet;
    }
 }
