/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugzilla.dialogs;


import org.eclipse.swt.SWT;
import org.eclipse.swt.events.ModifyEvent;
import org.eclipse.swt.events.ModifyListener;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Text;
import org.eclipse.team.bugs.dialogs.StatusDialog;
import org.eclipse.team.bugs.tools.SWTUtils;
import org.eclipse.team.bugs.tools.Utils;
import org.eclipse.team.bugzilla.model.BugzillaContainer;
import org.eclipse.team.bugzilla.model.BugzillaModel;

/**
 * Display a dialog to add a new bug to one of the bug
 * tracking systems.
 */
public class FolderNameDialog extends StatusDialog {

    private final class NameField implements ModifyListener {
        
        private final Text fNameText;
        private String fName;
        
        public NameField(Composite composite) {
            final Label label= new Label(composite, SWT.WRAP);
            label.setLayoutData(SWTUtils.createHFillGridData());
            label.setText(labelText);
            fNameText= new Text(composite, SWT.SINGLE | SWT.BORDER);
            fNameText.setLayoutData(SWTUtils.createHFillGridData());
            fNameText.setText(defaultName);
            fNameText.addModifyListener(this);
            fNameText.setFocus();
            updateEnablements(true);
        }
        
        public String getName() {
            return fName;
        }
        
        public void modifyText(ModifyEvent e) {
            updateEnablements(false);
        }

        private void updateEnablements(boolean firstTime) {
            final String text= fNameText.getText().trim();
            if (Utils.EMPTY_STRING.equals(text)) {
                fName= null;
                if (!firstTime) {
                    setErrorMessage(this, "Please enter a valid folder name.");
                } else {
                    setComplete(false);
                }
                
            } else if (isNameInUse(text)) {
                fName = null;
                setErrorMessage(this, "A folder already exists with this name.");
            } else {
                fName= text;
                if (!firstTime)
                    setErrorMessage(this, null);
                else 
                    setComplete(true);
            }
        }

        private boolean isNameInUse(String text) {
            if (!text.equals(defaultName)) {
	            BugzillaModel[] children = parentContainer.getChildren();
	            for (int i = 0; i < children.length; i++) {
                    BugzillaModel model = children[i];
                    if (model instanceof BugzillaContainer) {
                        if (text.equals(((BugzillaContainer)model).getName())) {
                            return true;
                        }
                    }
                }
            }
            return false;
        }
    }
    
    protected void setErrorMessage(Object key, String message) {
        super.setErrorMessage(key, message);
    }

    private NameField fNameField;
    private final BugzillaContainer parentContainer;
    private String labelText;
    private final String defaultName;
     
    public FolderNameDialog(Shell shell, BugzillaContainer parent, String title, String labelText, String defaultName) {
        super(shell, title);
        this.parentContainer = parent;
        this.labelText = labelText;
        this.defaultName = defaultName;
    }

    public String getName() {
        return fNameField.getName();
    }
    
    protected Composite createMainDialogArea(Composite parent) {
        
        final Composite composite= new Composite(parent, SWT.NONE);
        composite.setLayout(new GridLayout(1, false));
        
        fNameField= new NameField(composite);
        
        setComplete(false);

        return composite;
    }
 }    

