/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugzilla.model;

import org.eclipse.team.bugzilla.datatypes.CommentData;

/**
 * 
 */
public class BugzillaComment extends BugzillaModel implements Comparable { 
    
    private final BugzillaAttachment fAttachment;
    private final BugzillaReport fReport;
    private CommentData fCommentData;
    

    /* package */ BugzillaComment(BugzillaReport parent, CommentData comment) {
        super();
        fReport= parent;
        fCommentData= comment;
        if (fCommentData.attachmentDesc != null) {
            fAttachment= new BugzillaAttachment(this, fCommentData.attachmentDesc);
        }
        else 
            fAttachment= null;
        setParent(parent);
    }
    
    public BugzillaAttachment getAttachment() {
        return fAttachment;
     }

    public CommentData getCommentData() {
        return fCommentData;
    }
    
    public int compareTo(Object o) {
        if (o instanceof BugzillaComment) 
            return fCommentData.compareTo(((BugzillaComment)o).fCommentData);
        return -1;
    }
    
    public BugzillaReport getReport() {
        return fReport;
    }

    /* (non-Javadoc)
     * @see org.eclipse.team.bugzilla.model.BugzillaModel#getId()
     */
    public String getID() {
        return fCommentData.getId();
    }
    
    /* (non-Javadoc)
     * @see org.eclipse.team.bugzilla.model.BugzillaModel#hadErrors()
     */
    public boolean hadErrors() {
        return fReport.hadErrors();
    }
}




