/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.team.bugzilla.persistence;

import org.eclipse.team.bugzilla.BugzillaException;
import org.eclipse.team.bugzilla.model.BugzillaContainer;
import org.eclipse.team.bugzilla.model.BugzillaModel;
import org.osgi.service.prefs.Preferences;

/**
 * Provides persistence of container name
 */
public abstract class ContainerPersistenceAdapter extends AbstractPersistenceAdapter {

    private static final String NAME = "org.eclipse.team.bugzilla.name"; //$NON-NLS-1$

    /* (non-Javadoc)
     * @see org.eclipse.team.bugzilla.persistence.AbstractPersistenceAdapter#store(org.eclipse.team.bugzilla.model.BugzillaModel, org.osgi.service.prefs.Preferences)
     */
    protected void store(BugzillaModel element, Preferences node) {
        super.store(element, node);
        // The id of a query is the URL
        if (element instanceof BugzillaContainer) {
            BugzillaContainer c = (BugzillaContainer)element;
            node.put(NAME, c.getName());
        }
    }

    /* (non-Javadoc)
     * @see org.eclipse.team.bugzilla.persistence.AbstractPersistenceAdapter#create(org.eclipse.team.bugzilla.model.BugzillaModel, org.osgi.service.prefs.Preferences)
     */
    protected BugzillaModel restore(BugzillaContainer parent, Preferences node, String id) throws BugzillaException {
        final String name= node.get(NAME, EMPTY_STRING);
        return restore(parent, node, id, name);
    }

    /**
     * Retore the container with the given id and name from the given node.
     * @param parent the parent
     * @param node the preferences node
     * @param id the restored id
     * @param name the restored name
     */
    protected abstract BugzillaModel restore(BugzillaContainer parent, Preferences node, String id, String name) throws BugzillaException;

}
