/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.team.bugzilla.persistence;

import org.eclipse.team.bugzilla.BugzillaException;
import org.eclipse.team.bugzilla.model.BugzillaContainer;
import org.eclipse.team.bugzilla.model.BugzillaModel;
import org.osgi.service.prefs.Preferences;

/**
 * Interface which defines the persistence protocol for
 * bugzilla model elements
 */
public interface IPersistenceAdapter {

    /**
     * The element has been added so update the store and
     * flush to disk if requested.
     * @param element the added element
     * @param flush whether to flush to disk
     */
    void storeElement(BugzillaModel element, boolean flush);

    /**
     * Restore an element from the given node with the given element
     * as its parent
     * @param parent the parent element
     * @param node the node which was used to store the element
     * @param id the id of the stored element
     * @return the restored element
     */
    BugzillaModel restoreElement(BugzillaContainer parent, Preferences node, String id) throws BugzillaException;

    /**
     * The element has been removed so clear any persisted data for 
     * the element and
     * flush to disk if requested.
     * @param element the removed element
     * @param flush whether to flush to disk
     */
    void purgeChild(BugzillaModel element, BugzillaModel child, boolean flush);

    /**
     * Return the Preferences node that is used to store the 
     * information for the given element.
     * @param element the persisted element
     * @return the node used to persist the element
     */
//    Preferences getPreferences(Object element);
    
    String getId(Object element);

}
