/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugzilla.view;

import org.eclipse.jface.action.IMenuManager;
import org.eclipse.jface.action.MenuManager;
import org.eclipse.jface.action.Separator;
import org.eclipse.swt.custom.StyledText;
import org.eclipse.swt.events.FocusAdapter;
import org.eclipse.swt.events.FocusEvent;
import org.eclipse.team.bugs.extension.IViewerProxy;
import org.eclipse.team.bugzilla.actions.ApplyPatchAction;
import org.eclipse.team.bugzilla.actions.BugzillaCopyAction;
import org.eclipse.team.bugzilla.actions.BugzillaDeleteAction;
import org.eclipse.team.bugzilla.actions.BugzillaEditAction;
import org.eclipse.team.bugzilla.actions.BugzillaMoveAction;
import org.eclipse.team.bugzilla.actions.BugzillaPasteAction;
import org.eclipse.team.bugzilla.actions.BugzillaRenameAction;
import org.eclipse.team.bugzilla.actions.ClearHistoryAction;
import org.eclipse.team.bugzilla.actions.RefreshAction;
import org.eclipse.team.bugzilla.actions.ShowInBrowserAction;
import org.eclipse.team.bugzilla.actions.TextSelectAllAction;
import org.eclipse.team.bugzilla.tools.IBugzillaSelectionProvider;
import org.eclipse.ui.IWorkbenchActionConstants;
import org.eclipse.ui.actions.ActionFactory;

/**
 * 
 */
class ActionManager extends FocusAdapter {
    
    private final BugzillaDeleteAction fDeleteAction;
    private final BugzillaCopyAction fCopyAction;
    private final BugzillaPasteAction fPasteAction;
    private final BugzillaMoveAction fMoveAction;
    private final BugzillaRenameAction fRenameAction;
    private final BugzillaEditAction fEditAction;
    private final RefreshAction fRefreshAction;

    private final ShowInBrowserAction fShowInBrowserAction;
    private final ClearHistoryAction fClearHistoryAction;
    
    private final TextSelectAllAction fTextSelectAllAction;
	private ApplyPatchAction fApplyPatchAction;
    
    //private final BugzillaViewExtension fExtension;
    
    public ActionManager(BugzillaViewExtension extension) {
        
        //fExtension= extension;
        final IViewerProxy proxy= extension.getProxy();
        final IBugzillaSelectionProvider provider = extension.getBugzillaSelectionProvider();
        fDeleteAction= new BugzillaDeleteAction(proxy, provider);
        fPasteAction= new BugzillaPasteAction(proxy, provider);
        fCopyAction= new BugzillaCopyAction(proxy, extension, fPasteAction);
        fMoveAction= new BugzillaMoveAction(proxy, provider);
        fRenameAction= new BugzillaRenameAction(proxy, provider);
        fClearHistoryAction= new ClearHistoryAction(proxy, provider);
        fShowInBrowserAction= new ShowInBrowserAction(proxy, provider);
        fRefreshAction= new RefreshAction(proxy, provider);
        fTextSelectAllAction= new TextSelectAllAction(extension);
        fApplyPatchAction = new ApplyPatchAction(proxy, provider);
        fEditAction = new BugzillaEditAction(proxy, provider);
        
        proxy.registerGlobalAction(ActionFactory.DELETE.getId(), fDeleteAction);
        proxy.registerGlobalAction(ActionFactory.COPY.getId(), fCopyAction);
        proxy.registerGlobalAction(ActionFactory.PASTE.getId(), fPasteAction);
        //proxy.registerGlobalAction("Edit...", fEditAction);
        proxy.registerGlobalAction(ActionFactory.MOVE.getId(), fMoveAction);
        proxy.registerGlobalAction(ActionFactory.RENAME.getId(), fRenameAction);
        proxy.registerGlobalAction(ActionFactory.REFRESH.getId(), fRefreshAction);
        proxy.registerGlobalAction(ActionFactory.SELECT_ALL.getId(), fTextSelectAllAction);
    }
    
    public void fillContextMenu(IMenuManager menu) {
        if (fShowInBrowserAction.isEnabled())
            menu.add(fShowInBrowserAction);
        if (fClearHistoryAction.isEnabled())
            menu.add(fClearHistoryAction);
        if (fApplyPatchAction.isEnabled())
        	menu.add(fApplyPatchAction);
        if (fEditAction.isEnabled()) {
        	menu.insertAfter(ActionFactory.PASTE.getId(), fEditAction);
        }
    }

    public void updateActionEnablements() {
        fShowInBrowserAction.setEnablement();
        fDeleteAction.setEnablement();
        fCopyAction.setEnablement();
        fPasteAction.setEnablement();
        fMoveAction.setEnablement();
        fRefreshAction.setEnablement();
        fRenameAction.setEnablement();
        fClearHistoryAction.setEnablement();
        fTextSelectAllAction.setEnablement();
        fApplyPatchAction.setEnablement();
        fEditAction.setEnablement();
    }
    
    /* (non-Javadoc)
     * @see org.eclipse.swt.events.FocusAdapter#focusGained(org.eclipse.swt.events.FocusEvent)
     */
    public void focusGained(FocusEvent e) {
        updateActionEnablements();
    }

    /**
     * @param styledText
     */
    public void createTextContextMenu(StyledText styledText) {
        final MenuManager menu= new MenuManager(null);
        menu.add(fCopyAction);
        menu.add(fTextSelectAllAction);
        menu.add(new Separator(IWorkbenchActionConstants.MB_ADDITIONS));
        styledText.setMenu(menu.createContextMenu(styledText));
    }
}
