/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugzilla.view;

import org.eclipse.jface.action.IMenuManager;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.team.bugs.extension.BugViewExtension;
import org.eclipse.team.bugs.extension.IViewerProxy;
import org.eclipse.team.bugzilla.tools.IBugzillaSelectionProvider;


/**
 * This class implements the bugzilla view extension. It adds a text widget in the custom widget
 * area where information about items of the Bugzilla model are displayed. 
 */
public class BugzillaViewExtension extends BugViewExtension {
    
    private IViewerProxy fProxy;
    private TextPane fTextPane;
    private ActionManager fActionManager;
    private BugzillaSelectionProvider fBugzillaSelectionProvider;
    
    /* (non-Javadoc)
     * @see org.eclipse.team.bugs.extension.BugViewExtension#initialize(org.eclipse.team.bugs.extension.IViewerProxy)
     */
    public void initialize(IViewerProxy proxy) {
        fProxy= proxy;
        fBugzillaSelectionProvider= new BugzillaSelectionProvider();
        fProxy.addSelectionChangedListener(fBugzillaSelectionProvider);
        fActionManager= new ActionManager(this);
        new DropListener(proxy, new DragListener(proxy));
    }
    
    /* (non-Javadoc)
     * @see org.eclipse.team.bugs.extension.BugViewExtension#createCustomControl(org.eclipse.swt.widgets.Composite)
     */
    public Control createCustomControl(Composite parent) {
        
    	fTextPane= new TextPane(this, parent);

    	fTextPane.getStyledText().addFocusListener(fActionManager);
        fBugzillaSelectionProvider.addListener(fTextPane);
        fProxy.addOpenListener(fTextPane);
        fProxy.addProviderListener(fTextPane);
        
        return fTextPane.getControl();
    }
    
    /* (non-Javadoc)
     * @see org.eclipse.team.bugs.extension.BugViewExtension#fillContextMenu(org.eclipse.jface.viewers.IStructuredSelection, org.eclipse.jface.action.IMenuManager)
     */
    public void fillContextMenu(IStructuredSelection selection, IMenuManager menu) {
        fActionManager.fillContextMenu(menu);
    }

    /* (non-Javadoc)
     * @see org.eclipse.team.bugs.extension.BugViewExtension#updateActionEnablements(org.eclipse.jface.viewers.IStructuredSelection)
     */
    public void updateActionEnablements(IStructuredSelection selection) {
        fActionManager.updateActionEnablements();
    }
    
    /**
     * Get the bugzilla selection provider for this view extension.
     * @return the bugzilla selection provider.
     */
    public IBugzillaSelectionProvider getBugzillaSelectionProvider() {
        return fBugzillaSelectionProvider;
    }
    
    /**
     * Get the text provider for this view extension.
     * @return the text provider.
     */
    public TextPane getTextPane() {
        return fTextPane;
    }

    /**
     * Get the <code>IViewerProxy</code> of this <code>BugzillaViewExtension</code>.
     * @return the viewer proxy.
     */
    public IViewerProxy getProxy() {
        return fProxy;
    }
    
    public ActionManager getActionManager() {
        return fActionManager;
    }
}
