/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugzilla.xml;

import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;

import org.eclipse.team.bugzilla.datatypes.ReportData;
import org.xml.sax.SAXException;
import org.xml.sax.helpers.DefaultHandler;

/**
 * 
 */
public abstract class ReportHandler extends DefaultHandler {

    protected DateFormat fDateFormat;
    protected DateFormat fAttachmentDateFormat;
    
    private StringBuffer fBuffer;
    
    public ReportHandler() {
        super();
        fDateFormat= new SimpleDateFormat("yyyy-MM-dd HH:mm"); //$NON-NLS-1$
        fAttachmentDateFormat= new SimpleDateFormat("MM/dd/yy HH:mm"); //$NON-NLS-1$
    }

    public final void characters(char[] ch, int start, int length) throws SAXException {
        if (fBuffer == null)
            fBuffer= new StringBuffer();
        fBuffer.append(ch, start, length);
    }
    
    protected final String getPCDATA() {
        if (fBuffer == null)
            return ""; //$NON-NLS-1$
        
        final String pcdata= fBuffer.toString(); 
        fBuffer= null;
        return pcdata;
    }
    
    protected final void flushBuffer() {
        fBuffer= null;
    }

    protected final Date getDate() {
        try {
            return fDateFormat.parse(getPCDATA());
        } catch (ParseException e) {
            return null;
        }
    }
    
    protected final Date getAttachmentDate() {
        try {
            return fAttachmentDateFormat.parse(getPCDATA());
        } catch (ParseException e) {
            return null;
        }
    }

    
    public abstract ReportData getReportData();
}
