/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.team.bugzilla.xml;

import org.eclipse.team.bugzilla.BugzillaFactory;
import org.xml.sax.Attributes;
import org.xml.sax.SAXException;
import org.xml.sax.helpers.DefaultHandler;


/**
 * A handler to find out the version of Bugzilla a report has been
 * generated from.
 */
public final class VersionHandler extends DefaultHandler implements Tokens {
    
    private int fVersion= BugzillaFactory.VERSION_UNKNOWN;
    
    public void startElement(String uri, String localName, String qName, Attributes attributes) throws SAXException {

        final String name= "".equals(localName) ? qName : localName;  //$NON-NLS-1$
        
        final int token= LookupTable.get(name);
        
        if (token != BUGZILLA)
            return;
        
        final String value= attributes.getValue("version"); //$NON-NLS-1$
        
        if (value == null) 
            return;
         
        /* TODO: jpound - Add proper support for RH Bugzilla (rh bz#146667) */
        if (value.startsWith("2.16.")) { //$NON-NLS-1$
            fVersion= BugzillaFactory.VERSION_2_16;
        }
        
        else /*if (value.startsWith("2.18"))*/ {
            fVersion= BugzillaFactory.VERSION_2_18;
        }
    }
    
    public int getVersion() {
        return fVersion;
    }
}